.. raw:: html

   <h1 align="center">

RecoVoc

.. raw:: html

   </h1>

.. raw:: html

   <h4 align="center">

Projet de reconnaissance vocale développé en Python avec intégration de
la souris.

.. raw:: html

   </h4>

Status
------

|Codacy Badge| |Codacy Badge| |Code Health| |Build Status| |License|
|Supported Versions|

Pour commencer
--------------

S'assurer d'avoir les différents modules installés ainsi que leur
dépendances.

.. code:: bash

    git clone https://github.com/NicovincX2/RecoVoc #Cloner le répertoire
    cd RecoVoc/
    python3 -m pip install -e . #Pour l'installation des dépendances et du package
    cd recovoc
    python3 launch.py #Pour lancer le programme

Exemple d'utilisation basique:

.. code:: python

    from recovoc import speech

    speech.Recognition()

Prérequis
=========

| En cas d'erreur lors de l'installation consulter la liste de
  dépendances des modules utilisés.
| -
  `PyUserInput <https://github.com/SavinaRoja/PyUserInput#dependencies>`__
  -
  `SpeechRecognition <https://github.com/Uberi/speech_recognition#requirements>`__
  - `pyttsx3 <http://pyttsx.readthedocs.io/en/latest/install.html>`__

| Pour utiliser les options vidéos, le module ``ffmpeg`` est nécessaire.
  Sur Windows, le télécharger sur leur site officiel et suivre les
  instructions d'installation.
| Sur Linux:

.. code:: bash

    apt install ffmpeg

Installation
============

Sur la ligne de commande:

.. code:: bash

    python3 setup.py install

En cas d'erreurs lors de l'utilisation de type ``pcm_dmix`` sous Linux,
suivre la procédure suivante.

*Create a file called /etc/modprobe.d/default.conf with this content:*

::

    options snd_hda_intel index=1

*Then reboot.*

Description
-----------

-  Sur un portable, garder le volume de votre appareil en dessous d'une
   certaine limite à déterminer pour éviter les fausses détection
   vocales liées au retour d'audio.
-  Les frappes du clavier peuvent être détectées par Wit.ai dans la
   version anglaise du programme.

On constate quelquefois une interprétation erronée de bruit par Wit.ai
alors que Google ne comprends pas l'audio. Il peut alors être
souhaitable de modifier le paramètre
``recogniz.dynamic_energy_ratio = 5`` vers une valeur plus élevée.

Fichiers
~~~~~~~~

-  ``speech.py``: Code de base à exécuter.
-  ``messages.py``: Messages de l'application.
-  ``utils.py``: Fonctions utiles.
-  ``camera.py``: Intégration de la caméra.
-  ``recovoc.log``: Log des actions via le module logging.

Dossiers
~~~~~~~~

-  ``Images``: Images prises par la camera, ``cap-default`` sera écrasée
   si ``new=False``.
-  ``Snaps``: Images nécessaires à la création d'une vidéo, elles sont
   écrasées avant une nouvelle vidéo.
-  ``Videos``: Même fonctionnement que pour le dossier ``Images``.

TODO
~~~~

-  [x] Camera module tests
-  [ ] Camera module integration
-  [ ] speech.py tests
-  [ ] Sphinx Documentation
-  [ ] Travis build / Makefile test

Download
--------

Credits
-------

Ce programme utilise les modules Python suivants:

-  `SpeechRecognition <https://github.com/Uberi/speech_recognition>`__
-  `PyUserInput <https://github.com/SavinaRoja/PyUserInput>`__
-  `pytssx3 <https://github.com/nateshmbhat/pyttsx3>`__
-  `textblob <https://github.com/sloria/TextBlob>`__
-  `pygame <https://github.com/pygame/>`__

.. |Codacy Badge| image:: https://api.codacy.com/project/badge/Grade/96eaf2654ab046aa8b58da549de20472
   :target: https://www.codacy.com/app/NicovincX2/RecoVoc?utm_source=github.com&utm_medium=referral&utm_content=NicovincX2/RecoVoc&utm_campaign=Badge_Grade
.. |Codacy Badge| image:: https://api.codacy.com/project/badge/Coverage/96eaf2654ab046aa8b58da549de20472
   :target: https://www.codacy.com/app/NicovincX2/RecoVoc?utm_source=github.com&utm_medium=referral&utm_content=NicovincX2/RecoVoc&utm_campaign=Badge_Coverage
.. |Code Health| image:: https://landscape.io/github/NicovincX2/RecoVoc/master/landscape.svg?style=flat
   :target: https://landscape.io/github/NicovincX2/RecoVoc/master
.. |Build Status| image:: https://travis-ci.org/NicovincX2/RecoVoc.svg?branch=master
   :target: https://travis-ci.org/NicovincX2/RecoVoc
.. |License| image:: https://img.shields.io/badge/license-GPLv3-blue.svg
.. |Supported Versions| image:: https://img.shields.io/badge/python-3.3%2C%203.4%2C%203.5%2C%203.6-blue.svg

